@@ -107,7 +107,7 @@ unsafeCopyToPtr :: forall ty prim . PrimMonad prim
                 -> Ptr ty   -- ^ The destination address where the copy is going to start
                 -> prim ()
 unsafeCopyToPtr (Block blk) (Ptr p) = primitive $ \s1 ->
-    (# compatCopyByteArrayToAddr# blk 0# p (sizeofByteArray# blk) s1, () #)
+    (# copyByteArrayToAddr# blk 0# p (sizeofByteArray# blk) s1, () #)
 
 -- | Create a new array of size @n by settings each cells through the
 -- function @f.
